[gdb] Fix typos in comments
authorTom de Vries <tdevries@suse.de>
Thu, 17 Oct 2019 16:06:36 +0000 (18:06 +0200)
committerTom de Vries <tdevries@suse.de>
Thu, 17 Oct 2019 16:06:36 +0000 (18:06 +0200)
Fix typos in comments.  NFC.

Tested on x86_64-linux.

gdb/ChangeLog:

2019-10-17  Tom de Vries  <tdevries@suse.de>

* arm-nbsd-nat.c: Fix typos in comments.
* arm-tdep.c: Same.
* darwin-nat-info.c: Same.
* dwarf2read.c: Same.
* elfread.c: Same.
* event-top.c: Same.
* findvar.c: Same.
* gdbtypes.c: Same.
* hppa-tdep.c: Same.
* i386-tdep.c: Same.
* jit.c: Same.
* main.c: Same.
* mdebugread.c: Same.
* moxie-tdep.c: Same.
* nto-procfs.c: Same.
* osabi.c: Same.
* ppc-linux-tdep.c: Same.
* remote.c: Same.
* riscv-tdep.c: Same.
* s390-tdep.c: Same.
* sh-tdep.c: Same.
* sparc-linux-tdep.c: Same.
* sparc-nat.c: Same.
* stack.c: Same.
* target-descriptions.c: Same.
* top.c: Same.
* varobj.c: Same.

Change-Id: I6047967abd2d51c9000dea15184d19f4e952c3ff

28 files changed:
gdb/ChangeLog
gdb/arm-nbsd-nat.c
gdb/arm-tdep.c
gdb/darwin-nat-info.c
gdb/dwarf2read.c
gdb/elfread.c
gdb/event-top.c
gdb/findvar.c
gdb/gdbtypes.c
gdb/hppa-tdep.c
gdb/i386-tdep.c
gdb/jit.c
gdb/main.c
gdb/mdebugread.c
gdb/moxie-tdep.c
gdb/nto-procfs.c
gdb/osabi.c
gdb/ppc-linux-tdep.c
gdb/remote.c
gdb/riscv-tdep.c
gdb/s390-tdep.c
gdb/sh-tdep.c
gdb/sparc-linux-tdep.c
gdb/sparc-nat.c
gdb/stack.c
gdb/target-descriptions.c
gdb/top.c
gdb/varobj.c

index ced508f1f0a124c4eb8a0ba73e89b5f6874abfcd..e70e40eecb417762b53f85e4872ba86e30043ca0 100644 (file)
@@ -1,3 +1,33 @@
+2019-10-17  Tom de Vries  <tdevries@suse.de>
+
+       * arm-nbsd-nat.c: Fix typos in comments.
+       * arm-tdep.c: Same.
+       * darwin-nat-info.c: Same.
+       * dwarf2read.c: Same.
+       * elfread.c: Same.
+       * event-top.c: Same.
+       * findvar.c: Same.
+       * gdbtypes.c: Same.
+       * hppa-tdep.c: Same.
+       * i386-tdep.c: Same.
+       * jit.c: Same.
+       * main.c: Same.
+       * mdebugread.c: Same.
+       * moxie-tdep.c: Same.
+       * nto-procfs.c: Same.
+       * osabi.c: Same.
+       * ppc-linux-tdep.c: Same.
+       * remote.c: Same.
+       * riscv-tdep.c: Same.
+       * s390-tdep.c: Same.
+       * sh-tdep.c: Same.
+       * sparc-linux-tdep.c: Same.
+       * sparc-nat.c: Same.
+       * stack.c: Same.
+       * target-descriptions.c: Same.
+       * top.c: Same.
+       * varobj.c: Same.
+
 2019-10-16  Tom Tromey  <tom@tromey.com>
 
        * objfiles.h (struct objfile) <original_name>: Now const.
index 5160bfddf50138f13cc6da7383c35e1f41de7a8e..82c8ad5eedaf0bcdb3249dfff4a3021267478b60 100644 (file)
@@ -437,7 +437,7 @@ fetch_elfcore_registers (struct regcache *regcache,
 
 static struct core_fns arm_netbsd_elfcore_fns =
 {
-  bfd_target_elf_flavour,              /* core_flovour.  */
+  bfd_target_elf_flavour,              /* core_flavour.  */
   default_check_format,                        /* check_format.  */
   default_core_sniffer,                        /* core_sniffer.  */
   fetch_elfcore_registers,             /* core_read_registers.  */
index 5c1476af48b17f8a8d4d31169353ecf2b2a3b55b..fe5605c87005a69f169f506c7371c7f59b3581bd 100644 (file)
@@ -6809,7 +6809,7 @@ thumb2_decode_svc_copro (struct gdbarch *gdbarch, uint16_t insn1,
              if (bit_4 == 0) /* STC/STC2.  */
                return thumb_copy_unmodified_32bit (gdbarch, insn1, insn2,
                                                    "stc/stc2", dsc);
-             else /* LDC/LDC2 {literal, immeidate}.  */
+             else /* LDC/LDC2 {literal, immediate}.  */
                return thumb2_copy_copro_load_store (gdbarch, insn1, insn2,
                                                     regs, dsc);
            }
@@ -6954,7 +6954,7 @@ thumb_copy_16bit_ldr_literal (struct gdbarch *gdbarch, uint16_t insn1,
   return 0;
 }
 
-/* Copy Thumb cbnz/cbz insruction.  */
+/* Copy Thumb cbnz/cbz instruction.  */
 
 static int
 thumb_copy_cbnz_cbz (struct gdbarch *gdbarch, uint16_t insn1,
@@ -7329,7 +7329,7 @@ thumb_process_displaced_32bit_insn (struct gdbarch *gdbarch, uint16_t insn1,
          case 0:
            if (bit (insn1, 6))
              {
-               /* Load/store {dual, execlusive}, table branch.  */
+               /* Load/store {dual, exclusive}, table branch.  */
                if (bits (insn1, 7, 8) == 1 && bits (insn1, 4, 5) == 1
                    && bits (insn2, 5, 7) == 0)
                  err = thumb2_copy_table_branch (gdbarch, insn1, insn2, regs,
@@ -7390,7 +7390,7 @@ thumb_process_displaced_32bit_insn (struct gdbarch *gdbarch, uint16_t insn1,
                err = thumb_copy_unmodified_32bit (gdbarch, insn1, insn2,
                                                   "dp/pb", dsc);
            }
-         else /* Data processing (modified immeidate) */
+         else /* Data processing (modified immediate) */
            err = thumb_copy_unmodified_32bit (gdbarch, insn1, insn2,
                                               "dp/mi", dsc);
        }
index 4469cd52136f3c11cb94efba50e390b273cdfc20..b862c4485b003cfc9b67bf7b47105cb7a64fffcc 100644 (file)
@@ -810,7 +810,7 @@ info_mach_exceptions_command (const char *args, int from_tty)
        }
       else if (strcmp (args, "host") == 0)
        {
-         /* FIXME: This need a privilegied host port!  */
+         /* FIXME: This needs a privileged host port!  */
          kret = host_get_exception_ports
            (darwin_host_self, EXC_MASK_ALL, info.masks,
             &info.count, info.ports, info.behaviors, info.flavors);
index a78f818e0e8734c2ae99ed734b7bf3fa178493ea..5c705b0898b10aae21f26764f052e824830f6aba 100644 (file)
@@ -1486,7 +1486,7 @@ struct cu_partial_die_info
   cu_partial_die_info (struct dwarf2_cu *cu, struct partial_die_info *pdi)
     : cu (cu),
       pdi (pdi)
-  { /* Nothhing.  */ }
+  { /* Nothing.  */ }
 
 private:
   cu_partial_die_info () = delete;
@@ -14942,7 +14942,7 @@ producer_is_codewarrior (struct dwarf2_cu *cu)
   return cu->producer_is_codewarrior;
 }
 
-/* Return the default accessibility type if it is not overriden by
+/* Return the default accessibility type if it is not overridden by
    DW_AT_accessibility.  */
 
 static enum dwarf_access_attribute
index 53bdd3565943da00baf921521efb6571f2b26b06..1b5b4e0aa8086046fae20a93170c715e65488127 100644 (file)
@@ -1433,7 +1433,7 @@ const struct sym_fns elf_sym_fns_gdb_index =
   elf_symfile_read,            /* read a symbol file into symtab */
   NULL,                                /* sym_read_psymbols */
   elf_symfile_finish,          /* finished with file, cleanup */
-  default_symfile_offsets,     /* Translate ext. to int. relocatin */
+  default_symfile_offsets,     /* Translate ext. to int. relocation */
   elf_symfile_segments,                /* Get segment information from a file.  */
   NULL,
   default_symfile_relocate,    /* Relocate a debug section.  */
@@ -1450,7 +1450,7 @@ const struct sym_fns elf_sym_fns_debug_names =
   elf_symfile_read,            /* read a symbol file into symtab */
   NULL,                                /* sym_read_psymbols */
   elf_symfile_finish,          /* finished with file, cleanup */
-  default_symfile_offsets,     /* Translate ext. to int. relocatin */
+  default_symfile_offsets,     /* Translate ext. to int. relocation */
   elf_symfile_segments,                /* Get segment information from a file.  */
   NULL,
   default_symfile_relocate,    /* Relocate a debug section.  */
index 0b05b2f85a52e6ca0a5c79885f8ed30bcf24e766..0396dbcc52de74db3fbe32d41e33f04a3451c968 100644 (file)
@@ -421,7 +421,7 @@ display_gdb_prompt (const char *new_prompt)
 }
 
 /* Return the top level prompt, as specified by "set prompt", possibly
-   overriden by the python gdb.prompt_hook hook, and then composed
+   overridden by the python gdb.prompt_hook hook, and then composed
    with the prompt prefix and suffix (annotations).  */
 
 static std::string
@@ -1152,7 +1152,7 @@ handle_sigfpe (int sig)
   signal (sig, handle_sigfpe);
 }
 
-/* Event loop will call this functin to process a SIGFPE.  */
+/* Event loop will call this function to process a SIGFPE.  */
 static void
 async_float_handler (gdb_client_data arg)
 {
index e52ec8d7c92d2ea5f4e73b6302c60c941e73c539..3c8e631b87f47d724d58815ecb0cc46cc8ff4a30 100644 (file)
@@ -218,7 +218,7 @@ store_typed_address (gdb_byte *buf, struct type *type, CORE_ADDR addr)
    bytes.  If SOURCE_SIZE is greater than DEST_SIZE, then truncate the most
    significant bytes.  If SOURCE_SIZE is less than DEST_SIZE then either sign
    or zero extended according to IS_SIGNED.  Values are stored in memory with
-   endianess BYTE_ORDER.  */
+   endianness BYTE_ORDER.  */
 
 void
 copy_integer_to_size (gdb_byte *dest, int dest_size, const gdb_byte *source,
index a2b81c8690d6d443a47e28a481ea246d24772fec..fd1c765fed02095bb6396779f310bb68633fd0d9 100644 (file)
@@ -2733,7 +2733,7 @@ check_stub_method_group (struct type *type, int method_id)
     }
 }
 
-/* Ensure it is in .rodata (if available) by workarounding GCC PR 44690.  */
+/* Ensure it is in .rodata (if available) by working around GCC PR 44690.  */
 const struct cplus_struct_type cplus_struct_default = { };
 
 void
index 249d5c91bd176ac34a66a299a68cfab1942647ad..c307de8a3e444982c20cf48ce49b0811036af963 100644 (file)
@@ -88,7 +88,7 @@ static const struct objfile_key<hppa_objfile_private,
                                gdb::noop_deleter<hppa_objfile_private>>
   hppa_objfile_priv_data;
 
-/* Get at various relevent fields of an instruction word.  */
+/* Get at various relevant fields of an instruction word.  */
 #define MASK_5 0x1f
 #define MASK_11 0x7ff
 #define MASK_14 0x3fff
index ccec6d171b71afef6d4a01674e3e3a4020643a7a..3eb6fa4a5d7757ce00916952b3b3c50a352b2a06 100644 (file)
@@ -2956,7 +2956,7 @@ i386_return_value (struct gdbarch *gdbarch, struct value *function,
        || code == TYPE_CODE_UNION
        || code == TYPE_CODE_ARRAY)
        && !i386_reg_struct_return_p (gdbarch, type))
-      /* Complex double and long double uses the struct return covention.  */
+      /* Complex double and long double uses the struct return convention.  */
       || (code == TYPE_CODE_COMPLEX && TYPE_LENGTH (type) == 16)
       || (code == TYPE_CODE_COMPLEX && TYPE_LENGTH (type) == 24)
       /* 128-bit decimal float uses the struct return convention.  */
index af01b4d6c4fe3f1d997b6ab2867fed93e1c0b84c..08fd8623f9ccfd464aa2e421d28706e9019ab06f 100644 (file)
--- a/gdb/top.c
+++ b/gdb/top.c
@@ -86,7 +86,7 @@ extern void initialize_all_files (void);
 #define PREFIX(X) the_prompts.prompt_stack[the_prompts.top + X].prefix
 #define SUFFIX(X) the_prompts.prompt_stack[the_prompts.top + X].suffix
 
-/* Default command line prompt.  This is overriden in some configs.  */
+/* Default command line prompt.  This is overridden in some configs.  */
 
 #ifndef DEFAULT_PROMPT
 #define DEFAULT_PROMPT "(gdb) "
index 37a522be5d0def661f6e773bd537a687fa7eeb9a..09c42a352a50324e7be2d22c05c518a20e27c1a6 100644 (file)
@@ -1831,7 +1831,7 @@ install_variable (struct varobj *var)
   return true;                 /* OK */
 }
 
-/* Unistall the object VAR.  */
+/* Uninstall the object VAR.  */
 static void
 uninstall_variable (struct varobj *var)
 {
This page took 0.074641 seconds and 4 git commands to generate.
--- a/gdb/jit.c
+++ b/gdb/jit.c
@@ -76,7 +76,7 @@ struct target_buffer
   ULONGEST size;
 };
 
-/* Openning the file is a no-op.  */
+/* Opening the file is a no-op.  */
 
 static void *
 mem_bfd_iovec_open (struct bfd *abfd, void *open_closure)
index 7f873630d63fbda7bd4c23af2cacf60ade98f5a9..a77d6ec44c56526c3973680c7365c76f577e6079 100644 (file)
@@ -911,7 +911,7 @@ captured_main_1 (struct captured_main_args *context)
     }
 
   /* Lookup gdbinit files.  Note that the gdbinit file name may be
-     overriden during file initialization, so get_init_files should be
+     overridden during file initialization, so get_init_files should be
      called after gdb_init.  */
   std::string system_gdbinit;
   std::string home_gdbinit;
index eed714636dc1fda7710bca6d008a48c790d09a17..e76fe9aaf4297311dd66cf7adae53a9647623c37 100644 (file)
@@ -187,7 +187,7 @@ static const struct ecoff_debug_swap *debug_swap;
 
 static struct ecoff_debug_info *debug_info;
 
-/* Pointer to current file decriptor record, and its index.  */
+/* Pointer to current file descriptor record, and its index.  */
 
 static FDR *cur_fdr;
 static int cur_fd;
@@ -3729,7 +3729,7 @@ parse_partial_symbols (minimal_symbol_reader &reader,
          if (rh == f_idx)
            continue;
 
-         /* Do not add to dependeny list if psymtab was empty.  */
+         /* Do not add to dependency list if psymtab was empty.  */
          if (fdr_to_pst[rh].pst == NULL)
            continue;
          pst->dependencies[pst->number_of_dependencies++]
index 251c26735f5d5c026028d69904a7c2b5741826e6..81fdb7111c2af8c3605e80404089815cd4ba1e6d 100644 (file)
@@ -271,7 +271,7 @@ struct moxie_unwind_cache
 };
 
 /* Read an unsigned integer from the inferior, and adjust
-   endianess.  */
+   endianness.  */
 static ULONGEST
 moxie_process_readu (CORE_ADDR addr, gdb_byte *buf,
                     int length, enum bfd_endian byte_order)
index b9866c2259199a5b050a81050ffb5c50e641e22a..0a199e72248e90e6a188b18ce7348b7c5a1fda6f 100644 (file)
@@ -605,7 +605,7 @@ procfs_meminfo (const char *args, int from_tty)
              if (strcmp (map.info.path, printme.name))
                continue;
 
-             /* Lower debug_vaddr is always text, if nessessary, swap.  */
+             /* Lower debug_vaddr is always text, if necessary, swap.  */
              if ((int) map.info.vaddr < (int) printme.text.debug_vaddr)
                {
                  memcpy (&(printme.data), &(printme.text),
index cdf72a7664f82fe8140ffd8b5900848355b1081b..cc1652c5ad0d057b893ff2bf66164cdb9f738cbc 100644 (file)
@@ -415,7 +415,7 @@ check_note (bfd *abfd, asection *sect, char *note, unsigned int *sectsize,
   /* If this assertion triggers, increase MAX_NOTESZ.  */
   gdb_assert (notesz <= MAX_NOTESZ);
 
-  /* Check whether SECT is big enough to comtain the complete note.  */
+  /* Check whether SECT is big enough to contain the complete note.  */
   if (notesz > bfd_section_size (sect))
     return 0;
 
index ce3c727371f07f7e7d79751001ca32337ae20334..e692cffd7a16a2bea2e147eb350aa08aaa4c1256 100644 (file)
@@ -657,7 +657,7 @@ const struct regset ppc32_linux_tm_sprregset = {
    general-purpose regsets for 32-bit, 64-bit big-endian, and 64-bit
    little endian targets.  The ptrace and core file buffers for 64-bit
    targets use 8-byte fields for the 4-byte registers, and the
-   position of the register in the fields depends on the endianess.
+   position of the register in the fields depends on the endianness.
    The 32-bit regmap is the same for both endian types because the
    fields are all 4-byte long.
 
@@ -761,7 +761,7 @@ const struct regset ppc32_linux_cfprregset = {
 
 /* Regmaps for the Hardware Transactional Memory checkpointed vector
    regsets, for big and little endian targets.  The position of the
-   4-byte VSCR in its 16-byte field depends on the endianess.  */
+   4-byte VSCR in its 16-byte field depends on the endianness.  */
 
 static const struct regcache_map_entry ppc32_le_regmap_cvmx[] =
   {
index 73b510dd3958bfd1d064101d18f4b7c2759f9b19..f616569ff1c5f26040d3f0fb6faea0919f1554b2 100644 (file)
@@ -141,7 +141,7 @@ struct vCont_action_support
   bool S = false;
 };
 
-/* About this many threadisds fit in a packet.  */
+/* About this many threadids fit in a packet.  */
 
 #define MAXTHREADLISTRESULTS 32
 
@@ -3250,7 +3250,7 @@ remote_target::remote_unpack_thread_info_response (char *pkt,
     }
   copy_threadref (&info->threadid, &ref);
 
-  /* Loop on tagged fields , try to bail if somthing goes wrong.  */
+  /* Loop on tagged fields , try to bail if something goes wrong.  */
 
   /* Packets are terminated with nulls.  */
   while ((pkt < limit) && mask && *pkt)
@@ -3389,7 +3389,7 @@ remote_target::remote_get_threadlist (int startflag, threadref *nextthread,
   struct remote_state *rs = get_remote_state ();
   int result = 1;
 
-  /* Trancate result limit to be smaller than the packet size.  */
+  /* Truncate result limit to be smaller than the packet size.  */
   if ((((result_limit + 1) * BUF_THREAD_ID_SIZE) + 10)
       >= get_remote_packet_size ())
     result_limit = (get_remote_packet_size () / BUF_THREAD_ID_SIZE) - 2;
@@ -3411,8 +3411,8 @@ remote_target::remote_get_threadlist (int startflag, threadref *nextthread,
   if (!threadmatch (&rs->echo_nextthread, nextthread))
     {
       /* FIXME: This is a good reason to drop the packet.  */
-      /* Possably, there is a duplicate response.  */
-      /* Possabilities :
+      /* Possibly, there is a duplicate response.  */
+      /* Possibilities :
          retransmit immediatly - race conditions
          retransmit after timeout - yes
          exit
@@ -11283,7 +11283,7 @@ output_threadid (char *title, threadref *ref)
 {
   char hexid[20];
 
-  pack_threadid (&hexid[0], ref);      /* Convert threead id into hex.  */
+  pack_threadid (&hexid[0], ref);      /* Convert thread id into hex.  */
   hexid[16] = 0;
   printf_filtered ("%s  %s\n", title, (&hexid[0]));
 }
index 031fc8f9edec235847998268716b9e1ec1df6371..810b834463430c87b03b8ba6ed4a37da56024e40 100644 (file)
@@ -1010,7 +1010,7 @@ public:
       LUI,
       SD,
       SW,
-      /* These are needed for software breakopint support.  */
+      /* These are needed for software breakpoint support.  */
       JAL,
       JALR,
       BEQ,
index 329a1223963ee182c0033c04931cb6d85da71ba7..a4aae0736ddbc0022fa6e61c47f0dc068c2b5c8e 100644 (file)
@@ -2116,7 +2116,7 @@ s390_return_value (struct gdbarch *gdbarch, struct value *function,
 
 /* Frame unwinding.  */
 
-/* Implmement the stack_frame_destroyed_p gdbarch method.  */
+/* Implement the stack_frame_destroyed_p gdbarch method.  */
 
 static int
 s390_stack_frame_destroyed_p (struct gdbarch *gdbarch, CORE_ADDR pc)
@@ -5311,7 +5311,7 @@ ex:
        case 0xe383: /* MSGC - multiply single 64x64mem -> 64 */
        case 0xe398: /* ALC - add logical with carry */
        case 0xe399: /* SLB - subtract logical with borrow */
-       case 0xe727: /* LCBB - load count to block bounduary */
+       case 0xe727: /* LCBB - load count to block boundary */
        case 0xeb81: /* ICMY - insert characters under mask */
        case 0xebdc: /* SRAK - shift left single */
        case 0xebdd: /* SLAK - shift left single */
@@ -5537,7 +5537,7 @@ ex:
        case 0xe704: /* VLLEZ - vector load logical element and zero */
        case 0xe705: /* VLREP - vector load and replicate */
        case 0xe706: /* VL - vector load */
-       case 0xe707: /* VLBB - vector load to block bounduary */
+       case 0xe707: /* VLBB - vector load to block boundary */
        case 0xe712: /* VGEG - vector gather element */
        case 0xe713: /* VGEF - vector gather element */
        case 0xe722: /* VLVG - vector load vr element from gr */
@@ -6238,7 +6238,7 @@ ex:
            return -1;
          break;
 
-       /* 0xed42-0xed47 undefind */
+       /* 0xed42-0xed47 undefined */
 
        case 0xed48: /* SLXT - shift significand left */
        case 0xed49: /* SRXT - shift significand right */
@@ -6253,10 +6253,10 @@ ex:
            return -1;
          break;
 
-       /* 0xed4a-0xed4f undefind */
-       /* 0xed52-0xed53 undefind */
-       /* 0xed56-0xed57 undefind */
-       /* 0xed5a-0xed63 undefind */
+       /* 0xed4a-0xed4f undefined */
+       /* 0xed52-0xed53 undefined */
+       /* 0xed56-0xed57 undefined */
+       /* 0xed5a-0xed63 undefined */
        /* 0xed68-0xeda7 undefined */
 
        case 0xeda8: /* CZDT - convert to zoned */
index 8337a07501e295356405fe046142fa8304291054..48a388b2d8f3042f6839e80b0399f4c479bda644 100644 (file)
@@ -912,7 +912,7 @@ sh_frame_align (struct gdbarch *ignore, CORE_ADDR sp)
    not displace any of the other arguments passed in via registers R4
    to R7.  */
 
/* Helper function to justify value in register according to endianess.  */
 static const gdb_byte *
 sh_justify_value_in_reg (struct gdbarch *gdbarch, struct value *val, int len)
 {
@@ -942,7 +942,7 @@ sh_stack_allocsize (int nargs, struct value **args)
 }
 
 /* Helper functions for getting the float arguments right.  Registers usage
-   depends on the ABI and the endianess.  The comments should enlighten how
+   depends on the ABI and the endianness.  The comments should enlighten how
    it's intended to work.  */
 
 /* This array stores which of the float arg registers are already in use.  */
@@ -1045,7 +1045,7 @@ sh_treat_as_flt_p (struct type *type)
   /* Otherwise non-struct types are not treated as float.  */
   if (TYPE_CODE (type) != TYPE_CODE_STRUCT)
     return 0;
-  /* Otherwise structs with more than one memeber are not treated as float.  */
+  /* Otherwise structs with more than one member are not treated as float.  */
   if (TYPE_NFIELDS (type) != 1)
     return 0;
   /* Otherwise if the type of that member is float, the whole type is
@@ -1669,7 +1669,7 @@ sh_pseudo_register_read (struct gdbarch *gdbarch, readable_regcache *regcache,
                                              2, base_regnum, temp_buffer);
       if (status == REG_VALID)
        {
/* We must pay attention to the endiannes. */
          sh_register_convert_to_virtual (gdbarch, reg_nr,
                                          register_type (gdbarch, reg_nr),
                                          temp_buffer, buffer);
@@ -1712,7 +1712,7 @@ sh_pseudo_register_write (struct gdbarch *gdbarch, struct regcache *regcache,
       gdb_byte temp_buffer[4 * 2];
       base_regnum = dr_reg_base_num (gdbarch, reg_nr);
 
/* We must pay attention to the endiannes.  */
       sh_register_convert_to_raw (gdbarch, register_type (gdbarch, reg_nr),
                                  reg_nr, buffer, temp_buffer);
 
index 35bffdd772ee4e673d9e8d84854ca0ddd8394e4b..be3ff8d81418e7420701d420e8563ff6c401867f 100644 (file)
@@ -68,7 +68,7 @@ static const struct tramp_frame sparc32_linux_sigframe =
   SIGTRAMP_FRAME,
   4,
   {
-    { 0x821020d8, ULONGEST_MAX },              /* mov __NR_sugreturn, %g1 */
+    { 0x821020d8, ULONGEST_MAX },              /* mov __NR_sigreturn, %g1 */
     { 0x91d02010, ULONGEST_MAX },              /* ta  0x10 */
     { TRAMP_SENTINEL_INSN, ULONGEST_MAX }
   },
index 3685e5af410a9bd7bdc7e33abb0a82faf27bc7c5..8a124872c7f37ba33962bc7e14bb91b14faf4a8a 100644 (file)
@@ -308,7 +308,7 @@ sparc_xfer_wcookie (struct target_ops *ops, enum target_object object,
 void
 _initialize_sparc_nat (void)
 {
-  /* Deafult to using SunOS 4 register sets.  */
+  /* Default to using SunOS 4 register sets.  */
   if (sparc_gregmap == NULL)
     sparc_gregmap = &sparc32_sunos4_gregmap;
   if (sparc_fpregmap == NULL)
index c7c67fc7d5cbbbda2c394629ca4e5fd7981cb825..32c9c7380b43d8bb0ad296a1b106710b60cc07c6 100644 (file)
@@ -959,7 +959,7 @@ get_user_print_what_frame_info (gdb::optional<enum print_what> *what)
 /* Print information about frame FRAME.  The output is format according
    to PRINT_LEVEL and PRINT_WHAT and PRINT_ARGS.  For the meaning of
    PRINT_WHAT, see enum print_what comments in frame.h.
-   Note that PRINT_WHAT is overriden if FP_OPTS.print_frame_info
+   Note that PRINT_WHAT is overridden if FP_OPTS.print_frame_info
    != print_frame_info_auto.
 
    Used in "where" output, and to emit breakpoint or step
index f4368bbc05573f5348d49bb25191d0a232b9fa96..f4213bf5880661c7168e17e1ad11c085e1d9aac8 100644 (file)
@@ -1747,7 +1747,7 @@ static std::vector<xml_test_tdesc> xml_tdesc;
 
 #if GDB_SELF_TEST
 
-/* See target-descritpions.h.  */
+/* See target-descriptions.h.  */
 
 void
 record_xml_tdesc (const char *xml_file, const struct target_desc *tdesc)
@@ -912,7 +912,7 @@ sh_frame_align (struct gdbarch *ignore, CORE_ADDR sp)
    to R7.  */
 
-/* Helper function to justify value in register according to endianess.  */
+/* Helper function to justify value in register according to endianness.  */
 static const gdb_byte *
 sh_justify_value_in_reg (struct gdbarch *gdbarch, struct value *val, int len)
@@ -1669,7 +1669,7 @@ sh_pseudo_register_read (struct gdbarch *gdbarch, readable_regcache *regcache,
       if (status == REG_VALID)
        {
-         /* We must pay attention to the endiannes. */
+         /* We must pay attention to the endianness. */
          sh_register_convert_to_virtual (gdbarch, reg_nr,
                                          register_type (gdbarch, reg_nr),
@@ -1712,7 +1712,7 @@ sh_pseudo_register_write (struct gdbarch *gdbarch, struct regcache *regcache,
       base_regnum = dr_reg_base_num (gdbarch, reg_nr);
 
-      /* We must pay attention to the endiannes.  */
+      /* We must pay attention to the endianness.  */
       sh_register_convert_to_raw (gdbarch, register_type (gdbarch, reg_nr),
                                  reg_nr, buffer, temp_buffer);
index 78355a0315fb426120cb7770411cb4ab0808e56e..15d4fab8bebf52076251fcb619ea31b66542b5f8 100644 (file)